precision mediump float;

out lowp vec4	fragColor;
in highp float	relMag;
in highp float	colorIndex;
in highp float	fadeIn;
in highp float	twinkle;
in lowp float	starShaped;

void main()
{
	highp vec4 wht = vec4(2,2,2,2);
	highp vec4 blue = vec4(.5,1.6,2,2);
	highp vec4 red = vec4(2,1.8,.5,2);
	highp vec4 fragColorBase;
	
// translate our relmag into a base brightness
	highp float starBrightness = smoothstep(8.0,2.0,relMag);
	starBrightness = 0.2 + (0.8 * starBrightness);

// start with white, mix in warm and cool depending on colorIndex
	fragColorBase =  wht;
	fragColorBase = mix(fragColorBase, blue, smoothstep(-.5, .4, colorIndex));
	fragColorBase = mix(fragColorBase, red, smoothstep(.4, 2.0, colorIndex));
	
// we allow out-of-gamut values, so we clamp them here
	fragColorBase = clamp(fragColorBase, 0.0, 1.0);

// convert pointCoord from [0 - 1] to [-1 - 1]
	highp vec2 pointCoord_unit = (gl_PointCoord * 2.) - 1.;
	
// get our regular round-star intensity
	highp float simpleIntensity = sqrt(pointCoord_unit.x*pointCoord_unit.x + pointCoord_unit.y*pointCoord_unit.y);
	simpleIntensity = smoothstep(1.0, 0.7, simpleIntensity);
	
// get our star-shaped star intensity
	highp float starIntensity = (2.0 * ( 1.0 - sqrt(abs(pointCoord_unit.x*pointCoord_unit.y)) - 0.5) );

// reconcile the two intensities
	highp float intensity = (starIntensity * starShaped) + (simpleIntensity * (1.0 - starShaped));
	
	fragColor = fragColorBase * starBrightness * intensity * fadeIn;
}
